# LSB Test Execution Framework
# Desktop test module
#
# Copyright (C) 2007-2008 The Linux Foundation. All rights reserved.
#
# This program has been developed by ISP RAS for LF with some parts
# derived from lsb-autotest written by Jiri Dluhos <jdluhos@suse.cz>
# Copyright (C) 2005-2007 SuSE Linux Products GmbH
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

package Desktop_test;
use strict;

use Common;
use Packages;

use Tests::X11::X11_common;
@Desktop_test::ISA = qw(X11_common);

=head ##
Class Desktop_test Inherits X11_common
=cut ##

sub new {
    my $self  = X11_common->new();
    $self->{NAME} = "desktop";
    $self->{DISPLAYNAME} = "Desktop Tests";
    $self->{DESCRIPTION} = "LSB desktop test suites.";
    $self->{PACKAGES} .= "lsb-python lsb-tet3 lsb-xvfb lsb-xdg-utils lsb-test-desktop";
    $self->{SOURCES} .= " appbat runtime lsbdev";
    $self->{BETA_SOURCES} .= " appbat runtime lsbdev";
    $self->{SNAPSHOT_SOURCES} .= " appbat /snapshots/tet-harness "
                ."/snapshots/desktop-test /snapshots/lsb-xdg-utils";

    bless($self);
    return $self;
}

sub packages {
    my ($self, $lsb_ver) = @_;

    my $packages = Test_common::packages(@_);

    if ( defined $lsb_ver  ) {
        if ( $lsb_ver eq "3.0" || $lsb_ver eq "3.1" ) {
            $packages =~ s/ lsb-xvfb / /g;
			$packages =~ s/ lsb-xdg-utils / /g;
        }
    }
    return $packages;    
}

sub run {
    my ($self) = @_;
    
    # Short scenario:
    if ( $short_scenarios ) {
        inform("Use short scenario");
        my $result = backup_and_replace( "/opt/lsb/test/desktop/gtkvts/scenarios/func_scen",
            "$script_directory/Tests/X11/desktop_short_scen" );
		#if ( $result != 0 ) { inform ("Test will be skipped"); return 1; }
    }
    
    return X11_common::run(@_);
}

sub journal {
    my ($self) = @_;
    
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/Desktop::GTK Tests",
        "gtk_test", "$results_dir/test_journals/gtkvts_test.journal", 
        $self, $self->{START_TIME}, '' );
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/Desktop::Libpng Tests",
        "libpng_test", "$results_dir/test_journals/libpng_test.journal", 
        $self, '', '' );
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/Desktop::Libxml Tests",
        "libxml_test", "$results_dir/test_journals/libxml_test.journal",
        $self, '', '' );
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/Desktop::Qt3 Tests",
        "qt3_test", "$results_dir/test_journals/qt3_test.journal", 
        $self, '', '' );
    store_journal_info(
        "Certification Tests/Runtime Interface Tests/Desktop::Fontconfig Tests",
        "fontconfig_test", "$results_dir/test_journals/fontconfig_test.journal",
        $self, '', '' );
    
    if ( $desktop_qt4 ) {
        store_journal_info(
            "Certification Tests/Runtime Interface Tests/Desktop::Qt4 Tests",
            "qt4_test", "$results_dir/test_journals/qt4_test.journal",
            $self, '', '');
    }
    
    unless ( $lsb_version eq "3.0" || $lsb_version eq "3.1" ) {
        # Freetype test - since 3.2
        store_journal_info(
            "Certification Tests/Runtime Interface Tests/Desktop::FreeType Tests",
            "freetype_test", "$results_dir/test_journals/freetype_test.journal",
            $self, '', '');
        
        if ( $certification_mode ) {
            # Xft test is TRIAL since 3.2
            store_journal_info(
                    "Trial Use Tests (Optional)/Runtime Interface Tests/Desktop::Xft Tests",
                    "xft_test", "$results_dir/test_journals/xft_test.journal",
                    $self, '', '', 1 # Trial
                );

            # Xrender test is TRIAL since 3.2
            store_journal_info(
                    "Trial Use Tests (Optional)/Runtime Interface Tests/Desktop::XRender Tests",
                    "xrender_test", "$results_dir/test_journals/xrender_test.journal",
                    $self, '', '', 1 # Trial
                );
        } else {
            store_journal_info(
                    "Certification Tests/Runtime Interface Tests/Desktop::Xft Tests",
                    "xft_test", "$results_dir/test_journals/xft_test.journal",
                    $self, '', ''
                );

            store_journal_info(
                    "Certification Tests/Runtime Interface Tests/Desktop::XRender Tests",
                    "xrender_test", "$results_dir/test_journals/xrender_test.journal",
                    $self, '', ''
                );
        }
    }
    if ( $lsb_version ge "4.0" || $lsb_version eq "snapshot" ) {
        store_journal_info(
                "Certification Tests/Runtime Interface Tests/Desktop::Cairo Tests",
                "cairo_test", "$results_dir/test_journals/cairo_test.journal",
                $self, '', ''
            );
    }
}

sub cleanup {
    my ($self) = @_;
    
    X11_common::cleanup(@_);
    
    if ( $short_scenarios ) {
        my $scen_file = "/opt/lsb/test/desktop/gtkvts/scenarios/func_scen";
        if (-f "$scen_file.orig" ) {
            cmd ("cp -f $scen_file.orig $scen_file"); 
        }
    }
}

1; # return value
